/**********************************************************************\
**
**                         Copyright (c) 2009-2020 by
**                          HENSGSTLER GmbH, Aldingen
**
**      This  software  is furnished under a licence and may be used and
**      copied only in accordance with the terms  of  such  licence  and
**      with the inclusion of the above copyright notice.  This software
**      or any other copies thereof may not  be  provided  or  otherwise
**      made  available  to any other person.  No title to and ownership
**      of the software is hereby transferred.
**
**      The  information  in  this software is subject to change without
**      notice and should not be construed as a commitment by Hengstler.
**
**  Module:      C56_Api.h
**  Facility:    Hengstler C56 Linux Printer Driver Package / S684019
**  Application: C56 application programming interface (API) for linux (libC56Api.so)
**  Version:     R3-V1.04-FINAL - 2020FEB12
**  Environment: Linux Debian
**  Compiler:    gcc
**  Authors:     L. Tkac
**  Abstract:    Api Library header file
**  History:     R2-V1.01  / 2009JUN16 / TKA / Initial version
**               R3-V1.02d / 2011DEC09 / TKA / New API communication added (libusb)
**               R3-V1.02f / 2015NOV10 / TKA / Header info updated
**               R3-V1.03a / 2020JAN20 / TKA / Added x64 build options
**                                             Added new error messages  
**
\**********************************************************************/

#ifndef __C56_API_H
#define __C56_API_H

/*
** INCLUDES
*/

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>
   
/*
** MACROS
*/

//-- Error codes of application programming interface
#define D_C56_API_OPEN_FAILED                                              -1
#define D_C56_API_INVALID_DEVICE                                           -2
#define D_C56_API_DETACH_FAILED                                            -3
#define D_C56_API_CLAIM_FAILED                                             -4
#define D_C56_API_GET_ACTIVE_CONFIG_FAILED                                 -5
#define D_C56_API_NO_INTERFACE                                             -6
#define D_C56_API_ENDPOINT_COUNT_FAILURE                                   -7
#define D_C56_API_COMM_BUFFER_FAILURE                                      -8

//-- Error codes of "exo_api_printer_read" interface
#define D_C56_API_READ_BUFFER_FAILURE                                      -1
#define D_C56_API_READ_SAVING_FAILURE                                      -2
#define D_C56_API_READ_OVERFLOW                                            -3

/*
** TYPES
*/


/*
** VARIABLES
*/

/*
** FUNCTIONS
*/

//-- Inquiry function 
char *         C56_api_get_library_info    (void);

//-- Printer communication interface
intptr_t       C56_api_printer_open        (char * port); // e.g. port = "/dev/usb/lp0" or port = "/dev/bus/usb/003/002"
int            C56_api_printer_set_serial  (intptr_t printer, unsigned long baud_rate, unsigned char data_bits, unsigned char parity, unsigned char stop_bits);
void           C56_api_printer_close       (intptr_t printer);
int            C56_api_printer_write       (intptr_t printer, unsigned char * data, int size, unsigned long timeout_ms);
int            C56_api_printer_read        (intptr_t printer, unsigned char * data, int size, unsigned long timeout_ms);
int            C56_api_printer_clear       (intptr_t printer);

#ifdef __cplusplus
}
#endif

#endif // __C56_API_H







